==> keycloak-model-map-18.0.2-sources.jar: org/keycloak/models/map/role/MapRoleEntityFieldDelegate.java <==
package org.keycloak.models.map.role;
public class MapRoleEntityFieldDelegate extends org.keycloak.models.map.role.MapRoleEntity.AbstractRoleEntity implements org.keycloak.models.map.role.MapRoleEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.role.MapRoleEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.role.MapRoleEntity> entityFieldDelegate;
    public MapRoleEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.role.MapRoleEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.role.MapRoleEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,java.util.List<String>> getAttributes() {
        return (java.util.Map<String,java.util.List<String>>) entityFieldDelegate.get(org.keycloak.models.map.role.MapRoleEntityFields.ATTRIBUTES);
    }
    @SuppressWarnings("unchecked") @Override public void setAttributes(java.util.Map<String,java.util.List<String>> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.role.MapRoleEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.List<String> getAttribute(String p0) {
        return (java.util.List<String>) entityFieldDelegate.mapGet(org.keycloak.models.map.role.MapRoleEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setAttribute(String p0, java.util.List<String> p1) {
        entityFieldDelegate.mapPut(org.keycloak.models.map.role.MapRoleEntityFields.ATTRIBUTES, p0, p1);
    }
    @SuppressWarnings("unchecked") @Override public void removeAttribute(String p0) {
        entityFieldDelegate.mapRemove(org.keycloak.models.map.role.MapRoleEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.role.MapRoleEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.role.MapRoleEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isClientRole() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.role.MapRoleEntityFields.CLIENT_ROLE);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.role.MapRoleEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public String getClientId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.role.MapRoleEntityFields.CLIENT_ID);
    }
    @SuppressWarnings("unchecked") @Override public String getName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.role.MapRoleEntityFields.NAME);
    }
    @SuppressWarnings("unchecked") @Override public String getDescription() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.role.MapRoleEntityFields.DESCRIPTION);
    }
    @SuppressWarnings("unchecked") @Override public void setClientRole(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.role.MapRoleEntityFields.CLIENT_ROLE, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.role.MapRoleEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setClientId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.role.MapRoleEntityFields.CLIENT_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.role.MapRoleEntityFields.NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setDescription(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.role.MapRoleEntityFields.DESCRIPTION, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<String> getCompositeRoles() {
        return (java.util.Set<String>) entityFieldDelegate.get(org.keycloak.models.map.role.MapRoleEntityFields.COMPOSITE_ROLES);
    }
    @SuppressWarnings("unchecked") @Override public void setCompositeRoles(java.util.Set<String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.role.MapRoleEntityFields.COMPOSITE_ROLES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void addCompositeRole(String p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.role.MapRoleEntityFields.COMPOSITE_ROLES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void removeCompositeRole(String p0) {
        entityFieldDelegate.collectionRemove(org.keycloak.models.map.role.MapRoleEntityFields.COMPOSITE_ROLES, p0);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/role/MapRoleEntityFieldDelegate.java <==
package org.keycloak.models.map.role;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapRoleEntityFieldDelegate extends org.keycloak.models.map.role.MapRoleEntity.AbstractRoleEntity implements org.keycloak.models.map.role.MapRoleEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.role.MapRoleEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.role.MapRoleEntity> entityFieldDelegate;
    public MapRoleEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.role.MapRoleEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.role.MapRoleEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,java.util.List<String>> getAttributes() {
        return (java.util.Map<String,java.util.List<String>>) entityFieldDelegate.get(org.keycloak.models.map.role.MapRoleEntityFields.ATTRIBUTES);
    }
    @SuppressWarnings("unchecked") @Override public void setAttributes(java.util.Map<String,java.util.List<String>> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.role.MapRoleEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.List<String> getAttribute(String p0) {
        return (java.util.List<String>) entityFieldDelegate.mapGet(org.keycloak.models.map.role.MapRoleEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setAttribute(String p0, java.util.List<String> p1) {
        entityFieldDelegate.mapPut(org.keycloak.models.map.role.MapRoleEntityFields.ATTRIBUTES, p0, p1);
    }
    @SuppressWarnings("unchecked") @Override public void removeAttribute(String p0) {
        entityFieldDelegate.mapRemove(org.keycloak.models.map.role.MapRoleEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.role.MapRoleEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.role.MapRoleEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.role.MapRoleEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public String getClientId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.role.MapRoleEntityFields.CLIENT_ID);
    }
    @SuppressWarnings("unchecked") @Override public String getName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.role.MapRoleEntityFields.NAME);
    }
    @SuppressWarnings("unchecked") @Override public String getDescription() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.role.MapRoleEntityFields.DESCRIPTION);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.role.MapRoleEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setClientId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.role.MapRoleEntityFields.CLIENT_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.role.MapRoleEntityFields.NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setDescription(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.role.MapRoleEntityFields.DESCRIPTION, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<String> getCompositeRoles() {
        return (java.util.Set<String>) entityFieldDelegate.get(org.keycloak.models.map.role.MapRoleEntityFields.COMPOSITE_ROLES);
    }
    @SuppressWarnings("unchecked") @Override public void setCompositeRoles(java.util.Set<String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.role.MapRoleEntityFields.COMPOSITE_ROLES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void addCompositeRole(String p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.role.MapRoleEntityFields.COMPOSITE_ROLES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void removeCompositeRole(String p0) {
        entityFieldDelegate.collectionRemove(org.keycloak.models.map.role.MapRoleEntityFields.COMPOSITE_ROLES, p0);
    }
}
